{% extends "base.html" %}

{% load i18n %}

{% block title %}{% trans "Password change" %}{% endblock title %}

{% block content %}
    {% include "ksp_login/parts/single_form.html" %}
{% endblock content %}
